local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames')

L:RegisterTranslations('enUS', function() return {

	currmaxhp = "CurrHP/MaxHP",
	percenthp = "(HP%)",
	completehp = "CurrHP/MaxHP (HP%)",
	deficithp = "Amount of lost HP",	
	mh3completehp = "Same as completehp but uses MobHealth3",
	currmaxmp = "CurrMP/MaxMP",
	percentmp = "(MP%)",
	completemp = "CurrMP/MaxMP (MP%)",
	deficitmp = "Amount of lost MP",
	none = "None",
	
} end)

L:RegisterTranslations('koKR', function() return {

	currmaxhp = "현재생명력/최대생명력",
	percenthp = "(생명력%)",
	completehp = "현재생명력/최대생명력 (생명력%)",
	deficithp = "생명력을 잃어버린 양",	
	mh3completehp = "몹헬쓰3의 생명력 표시",
	currmaxmp = "현재마나/최대마나",
	percentmp = "(마나%)",
	completemp = "현재마나/최대마나 (마나%)",
	deficitmp = "마나를 잃어버린 양",
	none = "없음",
	
} end)

SimpleUnitFrames = AceLibrary("AceAddon-2.0"):new("AceModuleCore-2.0", "AceDB-2.0", "AceConsole-2.0")

SimpleUnitFrames.modulePrototype.core = SimpleUnitFrames

SimpleUnitFrames.defaults = {}
SimpleUnitFrames.consoleOptions = {
	type = 'group',
	args = {}
}

function SimpleUnitFrames:OnInitialize()

	self:RegisterDB("SimpleUnitFramesDB", "SimpleUnitFramesDBPerChar")
	self:RegisterDefaults('profile', self.defaults)
	
	for name, module in self:IterateModules() do
		if module.consoleOptions then
			self.consoleOptions.args[name] = module.consoleOptions
		end
		module.db = self.db.profile[name]		
	end

	self:RegisterChatCommand( { '/suf' }, self.consoleOptions )
	
end


function SimpleUnitFrames.modulePrototype:GetValueText(unitid, style)
	return SimpleUnitFrames.styles[style](unitid)
end


function SimpleUnitFrames.modulePrototype:PopulateOptions(optionTable, db)
	for option in pairs(optionTable.args) do
		for style in pairs(SimpleUnitFrames.styles) do
			optionTable.args[option].args[style] = {
				type = 'execute',				
				name = style,
				desc = L[style],
				func = function() db[option] = style end
			}
		end			
	end
end

SimpleUnitFrames.styles = {

	["currmaxhp"] = function(unitid) 
		return UnitHealth(unitid) .. '/' .. UnitHealthMax(unitid) 
	end,
	
	["percenthp"] = function(unitid) 
		return string.format( "%d%%", UnitHealth(unitid) * 100 / UnitHealthMax(unitid) ) 
	end,
	
	["completehp"] = function(unitid) 
		local curr, max = UnitHealth(unitid), UnitHealthMax(unitid)
		local percent = curr*100/max
		if max == 100 then -- Only return % when the exact HP is not know.
			return string.format( "(%d%%)", percent )
		else
			return string.format( "%d/%d (%d%%)", curr, max, percent)
		end
	end,
	
	["deficithp"] = function(unitid)
		return UnitHealth(unitid) - UnitHealthMax(unitid)
	end,
	
	["mh3completehp"] = function(unitid)
		local curr, max
		if MobHealth3 then
			curr, max = MobHealth3:GetUnitHealth(unitid)
		else
			curr, max = UnitHealth(unitid), UnitHealthMax(unitid)
		end
		local percent = curr*100/max
		if max == 100 then -- Only return % when the exact HP is not know.
			return string.format( "(%d%%)", percent )
		else
			return string.format( "%d/%d (%d%%)", curr, max, percent)
		end
	end,

	["currmaxmp"] = function(unitid) 
		return UnitMana(unitid) .. '/' .. UnitManaMax(unitid) 
	end,
	
	["percentmp"] = function(unitid) 
		return string.format( "%d%%", UnitMana(unitid) * 100 / UnitManaMax(unitid) ) 
	end,
	
	["completemp"] = function(unitid) 
		local curr, max = UnitMana(unitid), UnitManaMax(unitid)
		return string.format( "%d/%d (%d%%)", curr, max, curr*100/max)
	end,

	["deficitmp"] = function(unitid)
		return UnitMana(unitid) - UnitManaMax(unitid)
	end,
	
	["none"] = function() return "" end,
	
}

