local _G = getfenv(0)

local moduleName = "party"


local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Party')

L:RegisterTranslations('enUS', function() return {

	party_desc = "Options for party frames",
	
	mhp = "Middle Heath Text",
	rhp = "Right Health Text",
	mmp = "Middle Mana Text",
	rmp = "Right Mana Text",
	mhp_desc = "Set middle health text to one of the styles",
	rhp_desc = "Set right health text to one of the styles",
	mmp_desc = "Set middle mana text to one of the styles",
	rmp_desc = "Set right health text to one of the styles",
	
} end)

L:RegisterTranslations('koKR', function() return {

	party_desc = "파티 프레임에 대한 설정",
	
	mhp = "중간 생명력 글자",
	rhp = "오른쪽 생명력 글자",
	mmp = "중간 마나 글자",
	rmp = "오른쪽 마나 글자",
	mhp_desc = "중간 생명력 글자 표시 방법 선택",
	rhp_desc = "오른쪽 생명력 글자 표시 방법 선택",
	mmp_desc = "중간 마나 글자 표시 방법 선택",
	rmp_desc = "오른쪽 마나 글자 표시 방법 선택",
	
} end)

local Party = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

Party.core.defaults[moduleName] = {
	mhp = "percenthp",
	rhp = "currmaxhp",
	mmp = "percentmp",
	rmp = "currmaxmp",
}

Party.consoleOptions = {
	type = 'group',
	name = 'party',
	desc = L['party_desc'],
	args = {	
		mhp = {
			type = 'group',
			name = L['mhp'],
			desc = L['mhp_desc'],
			args = {}
		},
		rhp = {
			type = 'group',
			name = L['rhp'],
			desc = L['rhp_desc'],
			args = {}
		},
		mmp = {
			type = 'group',
			name = L['mmp'],
			desc = L['mmp_desc'],
			args = {}
		},
		rmp = {
			type = 'group',
			name = L['rmp'],
			desc = L['rmp_desc'],
			args = {}
		},
	}
}


function Party:OnInitialize()

	self:PopulateOptions(self.consoleOptions, self.db)
	
end



function Party:OnShow()

	if self.db then
		self:RegisterEvent("PARTY_MEMBERS_CHANGED", "UpdateAll");
		self:RegisterEvent("UNIT_HEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MAXHEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MANA", "OnManaChange" )
		self:RegisterEvent("UNIT_MAXMANA", "OnManaChange")
		self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_MAXENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_RAGE", "OnManaChange")
		self:RegisterEvent("UNIT_MAXRAGE", "OnManaChange")
		self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")		
		self:UpdateAll()
	end

end

function Party:OnHide()

	self:UnregisterAllEvents()
	
end

function Party:UpdateAll()
	for i=1, GetNumPartyMembers(), 1 do
		local unitid = 'party' .. i
		if UnitExists(unitid) then
			self:UpdateHealth(unitid)
			self:UpdateMana(unitid)
		end
	end
end

function Party:OnHealthChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateHealth(arg1)
	end
end

function Party:OnManaChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateMana(arg1)
	end
end
		

function Party:UpdateHealth(unitid)
	local i = string.sub(unitid, 6, 6)
	_G['SUF_PartyFrame'.. i .. 'HealthMiddle' ]:SetText( self:GetValueText(unitid, self.db.mhp) )
	_G['SUF_PartyFrame'.. i .. 'HealthRight' ]:SetText( self:GetValueText(unitid, self.db.rhp) )
end

function Party:UpdateMana(unitid)
	local i = string.sub(unitid, 6, 6)
	_G['SUF_PartyFrame'.. i .. 'ManaMiddle' ]:SetText( self:GetValueText(unitid, self.db.mmp) )
	_G['SUF_PartyFrame'.. i .. 'ManaRight' ]:SetText( self:GetValueText(unitid, self.db.rmp) )
end

-- Global name for PartyFrame to reach.
SUF_Party = Party